@@ -1,25 +1,15 @@
 {- arch-tag: HVIO main file
-Copyright (C) 2004-2006 John Goerzen <jgoerzen@complete.org>
+Copyright (c) 2004-2011 John Goerzen <jgoerzen@complete.org>
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
+All rights reserved.
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+For license and copyright information, see the file LICENSE
 -}
 
 {- |
    Module     : System.IO.HVIO
-   Copyright  : Copyright (C) 2004-2006 John Goerzen
-   License    : GNU GPL, version 2 or above
+   Copyright  : Copyright (C) 2004-2011 John Goerzen
+   License    : BSD3
 
    Maintainer : John Goerzen <jgoerzen@complete.org>
    Stability  : provisional
@@ -131,6 +121,7 @@ where
 
 import System.IO
 import System.IO.Error
+import qualified Control.Exception (catch, IOException)
 import Control.Concurrent.MVar
 import Data.IORef
 import Foreign.Ptr
@@ -297,7 +288,7 @@ class (Show a) => HVIO a where
                                      x -> accum `seq` loop (accum ++ [x])
                     handler e = if isEOFError e then return accum
                                 else ioError e
-                    in catch func handler
+                    in Control.Exception.catch func handler
             in
             do firstchar <- vGetChar h
                case firstchar of
@@ -311,7 +302,7 @@ class (Show a) => HVIO a where
                               c `seq` return (c : next)
                     handler e = if isEOFError e then return []
                                 else ioError e
-                    in catch func handler
+                    in Control.Exception.catch func handler
             in
             do loop
 
